@@ -6,7 +6,7 @@ Dancer::Plugin::Catmandu::SRU - SRU server backed by a searchable Catmandu::Stor
 
 =cut
 
-our $VERSION = '0.0401';
+our $VERSION = '0.0402';
 
 use Catmandu::Sane;
 use Dancer::Plugin;
@@ -125,7 +125,9 @@ XML
             my $layout = $schema->{layout};
             my $cql = $params->{query};
             if ($setting->{cql_filter}) {
-                $cql = "($setting->{cql_filter}) and ($cql)";
+                # space before the filter is to circumvent a bug in the Solr
+                # 3.6 edismax parser
+                $cql = "( $setting->{cql_filter}) and ( $cql)";
             }
 
             my $first = $request->startRecord || 1;
@@ -136,6 +138,7 @@ XML
 
             my $hits = eval {
                 $bag->search(
+                    %{ $setting->{default_search_params} || {} },
                     cql_query    => $cql,
                     sru_sortkeys => $request->sortKeys,
                     limit        => $limit,
